@@ -431,7 +431,7 @@ class ConfigInfoData(object):
         "WWPDB_DEPLOY_PRODUCTION_RU": (1000200000, 1001200000),
         # 'WWPDB_DEPLOY_NEXT_RU': (1000200000, 1001200000),
         "WWPDB_DEPLOY_PRODUCTION_UCSD": (1001200001, 1001300000),
-        "WWPDB_DEPLOY_PRODUCTION_BACKUP_RU": (1001310081, 1001350000),
+        "WWPDB_DEPLOY_PRODUCTION_BACKUP_RU": (1001310119, 1001350000),
         "WWPDB_DEPLOY_DEPGRP1_RU": (1001400001, 1001500000),
         "WWPDB_DEPLOY_DEPGRP2_RU": (1001400001, 1001500000),
         # 'PDBE_LEGACY': (1290000001, 1300000000), #PDBE legacy are incorporated into PDBE_PROD
@@ -529,7 +529,7 @@ class ConfigInfoData(object):
         "approval": ["Approval without corrections", "Approval with corrections"],
         "meta corrections": ["Other corrections"],
         "unlock": ["Re-upload files"],
-        "release": ["Release"],
+        "release": ["Release request"],
         "release_with_citation": ["Release with citation update"],
         "citation": ["Citation update"],
         "pre-submission": [
